@@ -26,6 +26,7 @@
 #define GCHEMPAINT_ELECTRON_H
 
 #include <gcu/object.h>
+#include <gccv/item-client.h>
 
 /*!\file*/
 namespace gcp {
@@ -40,7 +41,7 @@ extern gcu::TypeId ElectronType;
 /*!\class Electron gcp/electron.h
 Represents either single elecgtrons or electrons pairs.
 */
-class Electron: public gcu::Object
+class Electron: public gcu::Object, public gccv::ItemClient
 {
 public:
 /*!
@@ -72,30 +73,21 @@ POSITION_E, POSITION_N,...
 @param angle the angle from the east direction in the trigonometric convention.
 @param distance the distance from the center of the atom, or 0. if automatic.
 
-Sets the position of an electronn relative to its parent atom.
+Sets the position of an electron relative to its parent atom.
 */
 	void SetPosition (unsigned char Pos, double angle = 0., double distance = 0.);
 /*!
-@param w the GtkWidget inside which the Electron will be displayed.
-
-Used to add a representation of the Electron in the widget.
+Used to add a representation of the Electron in the view.
 */
-	void Add(GtkWidget* w) const;
+	void AddItem ();
 /*!
-@param w the GtkWidget inside which the Electron is displayed.
-
-Used to update the representation of the Electron in the widget.
-*/
-	void Update(GtkWidget* w) const;
-/*!
-@param w the GtkWidget inside which the Electron is displayed.
 @param state the selection state of the Electron.
 
 Used to set the selection state of the Electron inside the widget.
 The values of state might be gcp::SelStateUnselected, gcp::SelStateSelected,
 gcp::SelStateUpdating, or gcp::SelStateErasing.
 */
-	void SetSelected(GtkWidget* w, int state);
+	void SetSelected (int state);
 /*!
 @param xml the xmlDoc used to save the document.
 
@@ -131,6 +123,8 @@ Used to move and/or transform an Electron.
 */
 	void Transform2D (gcu::Matrix2D& m, double x, double y);
 
+	std::string Name ();
+
 private:
 	Atom* m_pAtom;
 	bool m_IsPair;
