@@ -25,6 +25,7 @@
 #ifndef GCHEMPAINT_TOOL_H
 #define GCHEMPAINT_TOOL_H
 
+#include <gcu/macros.h>
 #include <gtk/gtk.h>
 #include <libxml/tree.h>
 #include <vector>
@@ -105,6 +106,14 @@ is not pressed and the mouse is moved.
 */
 	void OnMotion (View* pView, gcu::Object* pObject, double x, double y, unsigned int state);
 /*!
+@param pView the view instance owning the event.
+@param state a bit-mask representing the state of the modifier keys (e.g. Control, Shift and Alt) and the pointer buttons. See GdkModifierType in GDK documentation.
+
+This method is called by the framework when the tool is active and the mouse is moved
+outside the current view.
+*/
+	void OnLeaveNotify (View* pView, unsigned int state);
+/*!
 @param x the horizontal position of the mouse when the event occured.
 @param y the vertical position of the mouse when the event occured.
 @param state a bit-mask representing the state of the modifier keys (e.g. Control, Shift and Alt) and the pointer buttons. See GdkModifierType in GDK documentation.
@@ -185,6 +194,13 @@ just returns \a false.
 */
 	virtual bool OnKeyPress (GdkEventKey *event);
 /*!
+Called by the framework for the active tool when a key release event occurs. Default
+just returns \a false.
+
+@return true to stop any further propagation of the event, false otherwise.
+*/
+	virtual bool OnKeyRelease (GdkEventKey *event);
+/*!
 Virtual method called by the framework whenthe active view, and hence the active
 document has changed, so that the tool can finish its current operation in the
 previously active document and update its options box according to
@@ -261,6 +277,11 @@ Gets the Application instance owning the tool.
 @return the Application instance.
 */
 	Application * GetApplication () {return m_pApp;}
+/*!
+Callback for a settings change event. Only tools which are dependent on some
+configuration key need to override this method. Default does nothing.
+*/
+	virtual void OnConfigChanged () {}
 
 protected:
 /*!
@@ -281,13 +302,20 @@ Default implementation does nothing.
 */
 	virtual void OnDrag ();
 /*!
-Called from OnDrag(double,double,unsigned int) when a motion event occured
+Called from OnMotion(gcp::View,double,double,unsigned int) when a motion event
 occured. This method must be overriden in
 derived classes if motion events are meaningful for the tool.
 Default implementation does nothing.
 */
 	virtual void OnMotion ();
 /*!
+Called from OnLeaveNotify(gcp::View,unsigned int) when a leave notify event
+occured. This method must be overriden in
+derived classes if leave notify events are meaningful for the tool.
+Default implementation does nothing.
+*/
+	virtual void OnLeaveNotify ();
+/*!
 Called from OnRelease(double,double,unsigned int) when a button release
 event occured. This method must be overriden in
 derived classes if button release events are meaningful for the tool.
@@ -311,12 +339,12 @@ y coordinate for the last mouse click (unless the tool modified it).
 	double m_y0;
 /*!
 x coordinate for the last mouse click (unless the tool modified it). It might
-be used by tools necessitating to pairs of coordinates.
+be used by tools necessitating two pairs of coordinates.
 */
 	double m_x1;
 /*!
 y coordinate for the last mouse click (unless the tool modified it). It might
-be used by tools necessitating to pairs of coordinates.
+be used by tools necessitating two pairs of coordinates.
 */
 	double m_y1;
 /*!
@@ -382,6 +410,8 @@ private:
 	double lastx, lasty;
 	std::string name;
 	bool m_bPressed;
+
+GCU_PROT_PROP (bool, OwnStatus)
 };
 
 }	// namespace gcp
