@@ -60,12 +60,6 @@ using namespace std;
 
 namespace gcp {
 
-/* bool on_event (GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
-{
-	View* pView = (View*) g_object_get_data(G_OBJECT(widget), "view");
-	return pView->OnEvent(item, event, widget);
-} */
-
 static bool on_destroy (GtkWidget *widget, View * pView)
 {
 	pView->OnDestroy (widget);
@@ -132,142 +126,6 @@ View::~View ()
 	// we don't need to delete the canvas, since destroying the widget does the job.
 }
 
-/*bool View::OnEvent (GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
-{
-	Application *App = m_pDoc->GetApplication ();
-	Theme *pTheme = m_pDoc->GetTheme ();
-	Tool* pActiveTool = App? App->GetActiveTool (): NULL;
-	if ((!m_pDoc->GetEditable ()) || (!pActiveTool))
-		return true;
-	m_CurObject = (item) ? (Object*) g_object_get_data (G_OBJECT (item), "object") : NULL;
-	if (item == (GnomeCanvasItem*) m_ActiveRichText) {
-		GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS (((GTypeInstance*) item)->g_class);
-		return klass->event (item, event);
-	} else if (pActiveTool->OnEvent (event))
-		return true;
-	m_pData = (WidgetData*) g_object_get_data (G_OBJECT (widget), "data");
-	m_pWidget = widget;
-	double x, y;
-	x = event->button.x;
-	y = event->button.y;
-	gnome_canvas_item_w2i (GNOME_CANVAS_ITEM (m_pData->Group), &x, &y);
-//	if (event->type == GDK_BUTTON_PRESS) {
-		if (item == m_pData->Background) {
-			item = NULL;
-			std::map<Object const*, GnomeCanvasGroup*>::iterator i = m_pData->Items.begin (),
-						end = m_pData->Items.end ();
-			Bond* pBond;
-			while (i != end) {
-				if ((*i).first->GetType () == gcu::BondType) {
-					pBond = (Bond*) (*i).first;
-					if (pBond->GetDist(x / pTheme->GetZoomFactor (), y / pTheme->GetZoomFactor ()) < (pTheme->GetPadding () + pTheme->GetBondWidth () / 2) / pTheme->GetZoomFactor ()) {
-						item = GNOME_CANVAS_ITEM ((*i).second);
-						m_CurObject = pBond;
-						break;
-					} else {
-						// may be one of the atoms might work
-						gcu::Atom *pAtom = pBond->GetAtom (0);
-						double xa, ya;
-						pAtom->GetCoords (&xa, &ya, NULL);
-						xa *= pTheme->GetZoomFactor ();
-						ya *= pTheme->GetZoomFactor ();
-						xa -= x;
-						ya -= y;
-						if (sqrt (xa * xa + ya * ya) < 3.5) {
-							//3.5 is arbitrary
-							m_CurObject = pAtom;
-							break;
-						}
-						pAtom = pBond->GetAtom (1);
-						pAtom->GetCoords (&xa, &ya, NULL);
-						xa *= pTheme->GetZoomFactor ();
-						ya *= pTheme->GetZoomFactor ();
-						xa -= x;
-						ya -= y;
-						if (sqrt (xa * xa + ya * ya) < 3.5) {
-							m_CurObject = pAtom;
-							break;
-						}
-					}
-				} else if ((*i).first->GetType () == gcu::AtomType) {
-					double xa, ya;
-					gcu::Atom *pAtom = (gcu::Atom*) (*i).first;
-					pAtom->GetCoords (&xa, &ya, NULL);
-					xa *= pTheme->GetZoomFactor ();
-					ya *= pTheme->GetZoomFactor ();
-					xa -= x;
-					ya -= y;
-					if (sqrt (xa * xa + ya * ya) < 3.5) {
-						//3.5 is arbitrary
-						m_CurObject = pAtom;
-						break;
-					}
-				}
-				i++;
-			}
-		}
-//	}
-	Object *pAtom;
-	if (m_CurObject && ((pAtom = m_CurObject->GetAtomAt (x / pTheme->GetZoomFactor (), y / pTheme->GetZoomFactor ()))))
-			m_CurObject = pAtom;
-	switch (event->type) {
-	case GDK_BUTTON_PRESS:
-		switch (event->button.button) {
-			case 1: {
-				if (m_Dragging) break;
-				bool result = pActiveTool->OnClicked(this, m_CurObject, x, y, event->button.state);
-				if (item && (item == (GnomeCanvasItem*)m_ActiveRichText)) {
-					GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS (((GTypeInstance*) item)->g_class);
-					return klass->event (item, event);
-				}
-				m_Dragging = result;
-				return true;
-			}
-			case 2: {
-				m_lastx = x;
-				m_lasty = y;
-				GtkClipboard *clipboard = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
-				OnPasteSelection (m_pWidget, clipboard);
-				return true;
-			}
-			case 3: {
-				bool result;
-				g_object_unref (m_UIManager);
-			 	m_UIManager = gtk_ui_manager_new ();
-				result = pActiveTool->OnRightButtonClicked (this, m_CurObject, event->button.x, event->button.y, m_UIManager);
-				if (m_CurObject)
-					result |= m_CurObject->BuildContextualMenu (m_UIManager, m_CurObject, x / GetZoomFactor (), y / GetZoomFactor ());
-				if (result) {
-					GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, "/popup");
-					gtk_menu_popup (GTK_MENU (w), NULL, NULL, NULL, NULL, 3,  gtk_get_current_event_time ());
-					return true;
-				}
-			}
-		}
-		break;
-	case GDK_MOTION_NOTIFY:
-		if (!m_Dragging)
-			break;
-		pActiveTool->OnDrag (x, y, event->button.state);
-		return true;
-	case GDK_BUTTON_RELEASE:
-	switch (event->button.button)
-		{
-		case 1:
-			if (!m_Dragging)
-				break;
-			m_Dragging = false;
-			pActiveTool->OnRelease (x, y, event->button.state);
-			m_pDoc->GetApplication ()->ClearStatus ();
-			return true;
-		}
-		break;
-	default:
-		break;
-	}
-	return false;
-}*/
-
 void View::AddObject (Object *pObject)
 {
 	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (pObject);
@@ -286,14 +144,10 @@ GtkWidget* View::CreateNewWidget ()
 {
 	if (m_Canvas)
 		return m_Canvas->GetWidget ();
-/*	gtk_widget_push_colormap (gdk_rgb_get_colormap ());
-	m_pWidget = gnome_canvas_gcp_new();
-	gtk_widget_pop_colormap ();*/
 	m_Canvas = new gccv::Canvas (this);
-	m_Canvas->SetBackgroundColor (RGBA_WHITE);
+	m_Canvas->SetBackgroundColor (GO_COLOR_WHITE);
 	m_pWidget = m_Canvas->GetWidget ();
 	m_Canvas->SetGap (3.); // FIXME: make this configurable
-//	GtkWidget* pWidget = (m_Widgets.size() > 0) ? m_Widgets.front () : NULL;
 	if (m_pWidget) {
 		g_object_set_data (G_OBJECT (m_pWidget), "view", this);
 		g_object_set_data (G_OBJECT (m_pWidget), "doc", m_pDoc);
@@ -301,39 +155,10 @@ GtkWidget* View::CreateNewWidget ()
 		m_pData->Canvas = m_pWidget;
 		g_object_set_data (G_OBJECT (m_pWidget), "data", m_pData);
 		m_pData->m_View = this;
-//		gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (m_pWidget), 1);
-//		gnome_canvas_set_scroll_region (GNOME_CANVAS (m_pWidget), 0, 0, m_width, m_height);
 		m_pData->Zoom = 1.0;
-/*		m_pData->Background = gnome_canvas_item_new (
-									gnome_canvas_root (GNOME_CANVAS (m_pWidget)),
-									gnome_canvas_rect_ext_get_type (),
-									"x1", 0.0,
-									"y1", 0.0,
-									"x2", (double) m_width,
-									"y2", (double) m_height,
-									"fill_color", "white",
-									NULL);
-		m_pData->Group = GNOME_CANVAS_GROUP (gnome_canvas_item_new (
-									gnome_canvas_root (GNOME_CANVAS (m_pWidget)),
-									gnome_canvas_group_ext_get_type (),
-									NULL));
-		if (m_pDoc->GetEditable ())
-			g_signal_connect (G_OBJECT (m_pData->Background), "event", G_CALLBACK (on_event), m_pWidget);*/
 		g_signal_connect (G_OBJECT (m_pWidget), "destroy", G_CALLBACK (on_destroy), this);
 		gtk_widget_show (m_pWidget);
-//		m_Widgets.push_back (m_pWidget);
-/*		if (pWidget) {
-			WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (pWidget), "data");
-			std::map<Object const*, GnomeCanvasGroup*>::iterator i, iend = pData->Items.end ();
-			for (i = pData->Items.begin (); i != iend; i++)
-				if ((*i).first->GetType () != gcu::BondType)
-				 (*i).first->Add (m_pWidget);
-			for (i = pData->Items.begin (); i != iend; i++)
-				if ((*i).first->GetType () == gcu::BondType)
-				 (*i).first->Add (m_pWidget);
-		} else*/ {
-			UpdateFont ();
-		}
+		UpdateFont ();
 	}
 	return m_pWidget;
 }
@@ -347,17 +172,6 @@ void View::OnDestroy (GtkWidget* widget)
 		delete m_pDoc;
 }
 
-/*GnomeCanvasItem* View::GetCanvasItem (GtkWidget* widget, Object* Object)
-{
-	WidgetData* pData = reinterpret_cast<WidgetData*> (g_object_get_data (G_OBJECT (widget), "data"));
-	if ((!pData) || (pData->m_View != this))
-		return NULL;
-	GnomeCanvasItem *result = reinterpret_cast<GnomeCanvasItem*> (pData->Items[Object]);
-	if (!result)
-		pData->Items.erase (Object);
-	return result;
-}*/
-
 void View::Update (Object *pObject)
 {
 	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (pObject);
@@ -440,6 +254,7 @@ void View::OnDeleteSelection (GtkWidget* w)
 				Op->AddObject (pObject);
 			pObject->Lock ();
 			parent = pObject->GetParent ();
+			m_pData->Unselect (pObject);
 			m_pDoc->Remove (pObject);
 			if (parent)
 				parent->EmitSignal (OnChangedSignal);
@@ -820,6 +635,8 @@ bool View::OnKeyRelease (G_GNUC_UNUSED GtkWidget* w, GdkEventKey* event)
 {
 	Application *pApp = m_pDoc->GetApplication ();
 	Tool *pActiveTool = pApp->GetActiveTool ();
+	if (pActiveTool->OnKeyRelease (event))
+		return true;
 	switch(event->keyval) {
 	case GDK_Shift_L:
 	case GDK_Shift_R:
@@ -905,9 +722,7 @@ void View::ExportImage (string const &filename, const char* type, int resolution
 		GError *error = NULL;
 		GsfOutput *output = gsf_output_gio_new_for_uri (filename.c_str (), &error);
 		if (error) {
-			gchar * mess = g_strdup_printf (_("Could not create stream!\n%s"), error->message);
-			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (m_pWidget)), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
-			g_free (mess);
+			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (m_pWidget)), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Could not create stream!\n%s"), error->message);
 			gtk_dialog_run (GTK_DIALOG (message));
 			gtk_widget_destroy (message);
 			g_error_free (error);
@@ -933,9 +748,7 @@ void View::ExportImage (string const &filename, const char* type, int resolution
 		GError *error = NULL;
 		GsfOutput *output = gsf_output_gio_new_for_uri (filename.c_str (), &error);
 		if (error) {
-			gchar * mess = g_strdup_printf (_("Could not create stream!\n%s"), error->message);
-			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (m_pWidget)), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
-			g_free (mess);
+			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (m_pWidget)), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Could not create stream!\n%s"), error->message);
 			gtk_dialog_run (GTK_DIALOG (message));
 			gtk_widget_destroy (message);
 			g_error_free (error);
@@ -1028,8 +841,8 @@ GdkPixbuf *View::BuildPixbuf (int resolution)
 		cairo_set_source_rgb (cr, 1., 1., 1.);
 		cairo_paint (cr);
 	}
-	cairo_translate (cr, -floor (rect.x0), -floor (rect.y0));
 	cairo_scale (cr, zoom, zoom);
+	cairo_translate (cr, -floor (rect.x0), -floor (rect.y0));
 	m_Canvas->Render (cr, false);
 	int rowstride = cairo_image_surface_get_stride (surface);
 	unsigned char *data = cairo_image_surface_get_data (surface);
@@ -1106,18 +919,8 @@ void View::UpdateTheme ()
 void View::Render (cairo_t *cr)
 {
 	m_pData->ShowSelection(false);
-//	Object* pObj = NULL;
-/*	if (m_ActiveRichText) {
-		pObj = (Object*) g_object_get_data (G_OBJECT (m_ActiveRichText), "object");
-		if (pObj) pObj->SetSelected (m_pWidget, SelStateUnselected);
-	}*/
 	m_Canvas->Render (cr, true);
-/*	GnomeCanvas *canvas = GNOME_CANVAS (m_pWidget);
-	gnome_canvas_update_now (canvas);
-	g_printable_draw_cairo (G_PRINTABLE (m_pData->Group), cr);*/
 	m_pData->ShowSelection (true);
-/*	if (pObj)
-		pObj->SetSelected (SelStateUpdating);*/
 }
 
 // Events
@@ -1137,10 +940,6 @@ bool View::OnButtonPressed (gccv::ItemClient *client, unsigned button, double x,
 	case 1: {
 		if (m_Dragging) break;
 		bool result = pActiveTool->OnClicked (this, m_CurObject, x, y, state);
-/*		if (item && (item == (GnomeCanvasItem*)m_ActiveRichText)) {
-			GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS (((GTypeInstance*) item)->g_class);
-			return klass->event (item, event);
-		}*/
 		m_Dragging = result;
 		return true;
 	}
@@ -1180,7 +979,8 @@ bool View::OnButtonReleased (G_GNUC_UNUSED gccv::ItemClient *client, unsigned bu
 			break;
 		m_Dragging = false;
 		pActiveTool->OnRelease (x, y, state);
-		m_pDoc->GetApplication ()->ClearStatus ();
+		if (!pActiveTool->GetOwnStatus ())
+			m_pDoc->GetApplication ()->ClearStatus ();
 		return true;
 	}
 	return true;
@@ -1213,11 +1013,20 @@ bool View::OnMotion (gccv::ItemClient *client, double x, double y, unsigned stat
 	return true;
 }
 
+bool View::OnLeaveNotify (unsigned state)
+{
+	Application *App = m_pDoc->GetApplication ();
+	Tool* pActiveTool = App? App->GetActiveTool (): NULL;	
+	if (m_pDoc->GetEditable () && pActiveTool)
+		pActiveTool->OnLeaveNotify (this, state);
+	return true;
+}
+
 void View::SetSelectionState (Object *object, int state)
 {
 	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (object);
 	if (client)
-		client->SetSelected (state);
+		client->SetSelected (state);	
 	map<string, Object*>::iterator i;
 	Object *child = object->GetFirstChild (i);
 	while (child) {
