@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/3d/window.cc 
  *
- * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -77,10 +77,10 @@ static void on_color_changed (GOActionComboColor *combo, gc3dWindow *window)
 {
 	GOColor color = go_action_combo_color_get_color (combo, FALSE);
 	gc3dView *View = window->GetView ();
-	View->SetRed (DOUBLE_RGBA_R (color));
-	View->SetGreen (DOUBLE_RGBA_G (color));
-	View->SetBlue (DOUBLE_RGBA_B (color));
-	View->SetAlpha (DOUBLE_RGBA_A (color));
+	View->SetRed (GO_COLOR_DOUBLE_R (color));
+	View->SetGreen (GO_COLOR_DOUBLE_G (color));
+	View->SetBlue (GO_COLOR_DOUBLE_B (color));
+	View->SetAlpha (GO_COLOR_DOUBLE_A (color));
 	View->Update ();
 }
 
@@ -125,7 +125,7 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, gc3dWindow *window)
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GChem3D is a molecular structures viewer for Gnome");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2004-2008 Jean Bréfort\n");
+	const gchar * copyright = _("Copyright © 2004-2010 Jean Bréfort\n");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -256,6 +256,7 @@ gc3dWindow::gc3dWindow (gc3dApplication *App, gc3dDocument *Doc)
 
 	m_Window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL));
 	gtk_window_set_default_size (m_Window, 250, 280);
+	gtk_window_set_icon_name (m_Window, App->GetIconName ().c_str ());
 	g_signal_connect (G_OBJECT (m_Window), "delete-event", G_CALLBACK (on_delete_event), this);
 
 	vbox = gtk_vbox_new (FALSE, 0);
@@ -264,7 +265,7 @@ gc3dWindow::gc3dWindow (gc3dApplication *App, gc3dDocument *Doc)
 	action_group = gtk_action_group_new ("MenuActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), this);
-	GOActionComboColor *combo = go_action_combo_color_new ("Background", "gcu_Background", "", RGBA_BLACK, NULL);
+	GOActionComboColor *combo = go_action_combo_color_new ("Background", "gcu_Background", "", GO_COLOR_BLACK, NULL);
 	g_object_set (G_OBJECT (combo), "label", _("Background color"), "tooltip",
 		_("Choose a new background color"), NULL);
 	g_signal_connect (G_OBJECT (combo), "activate", G_CALLBACK (on_color_changed), this);
