@@ -4,7 +4,7 @@
  * Gnome Crystal
  * application.cc 
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -28,13 +28,10 @@
 #include "prefs.h"
 #include "window.h"
 #include <gcu/filechooser.h>
-#include <goffice/utils/go-image.h>
+#include <gcu/loader.h>
 #include <gsf/gsf-output-gio.h>
-#include <glade/glade.h>
-#include <gtk/gtk.h>
 #include <cairo-pdf.h>
 #include <cairo-ps.h>
-#include <gio/gio.h>
 #include <glib/gi18n.h>
 #include <cstring>
 
@@ -43,8 +40,35 @@ using namespace std;
 
 static unsigned short nNewDocs = 1;
 
+static Object *CreateAtom ()
+{
+	return new gcAtom ();
+}
+
+bool gcApplication::m_bInit = false;
+
 gcApplication::gcApplication(): Application ("gcrystal")
 {
+	gcu::Loader::Init ();
+	m_SupportedMimeTypes.push_back ("application/x-gcrystal");
+	m_WriteableMimeTypes.push_back ("application/x-gcrystal");
+	// browse available loaders
+	map<string, LoaderStruct>::iterator it;
+	bool found = Loader::GetFirstLoader (it);
+	while (found) {
+		if ((*it).second.supportsCrystals) {
+			if ((*it).second.read)
+				AddMimeType (m_SupportedMimeTypes, (*it).first);
+			// FIXME: add write support for cif and cml
+			if ((*it).second.write)
+				AddMimeType (m_WriteableMimeTypes, (*it).first);
+		}
+		found = Loader::GetNextLoader (it);
+	}
+	if (!m_bInit) {
+		Object::AddType ("atom", CreateAtom, AtomType);
+		m_bInit = true;
+	}
 }
 
 gcApplication::~gcApplication ()
@@ -64,12 +88,7 @@ gcDocument *gcApplication::OnFileNew ()
 
 void gcApplication::OnFileOpen ()
 {
-	list<string> l;
-	l.push_front ("application/x-gcrystal");
-#ifdef HAVE_OPENBABEL_2_2
-	l.push_front ("chemical/x-cif");
-#endif
-	FileChooser (this, false, l);
+	FileChooser (this, false, m_SupportedMimeTypes);
 }
 
 void gcApplication::OnFileSave ()
@@ -84,9 +103,7 @@ void gcApplication::OnFileSave ()
 
 void gcApplication::OnFileSaveAs ()
 {
-	list<string> l;
-	l.push_front ("application/x-gcrystal");
-	FileChooser (this, true, l, m_pActiveDoc);
+	FileChooser (this, true, m_WriteableMimeTypes, m_pActiveDoc);
 }
 
 bool gcApplication::OnFileClose ()
@@ -141,6 +158,7 @@ gcDocument* gcApplication::GetDoc (const char* filename)
 enum {
 	GCRYSTAL,
 	CIF,
+	CML,
 	VRML,
 	PDF,
 	PS,
@@ -167,8 +185,10 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 	string filename2 = filename;
 	if (bSave) {
 		char const *pixbuf_type = NULL;
-		if (!strcmp (mime_type, "chemica/x-cif"))
+		if (!strcmp (mime_type, "chemical/x-cif"))
 			type = CIF;
+		if (!strcmp (mime_type, "chemical/x-cml"))
+			type = CML;
 		else if (!strcmp (mime_type, "model/vrml"))
 			type = VRML;
 		else if (!strcmp (mime_type, "image/x-eps"))
@@ -187,6 +207,9 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		case CIF:
 			ext = ".cif";
 			break;
+		case CML:
+			ext = ".cml";
+			break;
 		case VRML:
 			ext = ".wrl";
 			break;
@@ -212,13 +235,11 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		gint result = GTK_RESPONSE_YES;
 		if (err) {
 			char *unescaped = g_uri_unescape_string (filename2.c_str (), NULL);
-			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
+			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("File %s\nexists, overwrite?"), unescaped));
 			g_free (unescaped);
-			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gcrystal");
 			result = gtk_dialog_run (Box);
 			gtk_widget_destroy (GTK_WIDGET (Box));
-			g_free (message);
 			if (result == GTK_RESPONSE_YES) {
 				// destroy the old file if needed
 				if (err) {
@@ -226,14 +247,12 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 					g_file_delete (file, NULL, &error);
 					if (error) {
 						char *unescaped = g_uri_unescape_string (filename2.c_str (), NULL);
-						gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), unescaped, error->message);
+						GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("Error while processing %s:\n%s"), unescaped, error->message));
 						g_free (unescaped);
 						g_error_free (error);
-						GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 						gtk_window_set_icon_name (GTK_WINDOW (Box), "gcrystal");
 						result = gtk_dialog_run (Box);
 						gtk_widget_destroy (GTK_WIDGET (Box));
-						g_free (message);
 						g_object_unref (file);
 						return false;
 					}
@@ -259,6 +278,8 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 				Doc->RenameViews ();
 				break;
 			case CIF:
+			case CML:
+				Save (filename2, mime_type, Doc, ContentTypeCrystal);
 				break;
 			case VRML:
 				Doc->OnExportVRML (filename2);
@@ -272,9 +293,7 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 				GError *error = NULL;
 				GsfOutput *output = gsf_output_gio_new_for_uri (filename2.c_str (), &error);
 				if (error) {
-					gchar * mess = g_strdup_printf (_("Could not create stream!\n%s"), error->message);
-					GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
-					g_free (mess);
+					GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Could not create stream!\n%s"), error->message);
 					gtk_dialog_run (GTK_DIALOG (message));
 					gtk_widget_destroy (message);
 					g_error_free (error);
@@ -306,6 +325,8 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		if (!strcmp (mime_type, "application/x-gcrystal"));
 		else if (!strcmp (mime_type, "chemical/x-cif"))
 			type = CIF;
+		else if (!strcmp (mime_type, "chemical/x-cml"))
+			type = CML;
 		else
 			return true;
 		gcDocument *xDoc = GetDoc (filename);
@@ -319,21 +340,28 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 			if (!Doc->GetDirty ())
 				return true;
 			else {
-				gchar* str = g_strdup_printf (_("\"%s\" has been modified since last saving. Do you wish to come back to saved version?"), Doc->GetTitle ());
-				GtkWidget* mbox = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
+				GtkWidget* mbox = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("\"%s\" has been modified since last saving. Do you wish to come back to saved version?"), Doc->GetTitle ());
 				int res = gtk_dialog_run (GTK_DIALOG (mbox));
 				if (res != GTK_RESPONSE_YES)
 					return true;
 			}
 		}
-		if ((type == GCRYSTAL)? Doc->Load (filename):
-#ifdef HAVE_OPENBABEL_2_2
-						Doc->Import (filename, mime_type)) {
-#else
-						false) {
-#endif
+		ContentType ctype = Load (filename, mime_type, Doc);
+		if (ctype == ContentTypeCrystal) {
+			Doc->Loaded ();
+			Doc->SetReadOnly (true);
+			Doc->UpdateAllViews ();
+			goto normal_exit;
+		} else if (ctype != ContentTypeUnknown) {
+			// FIXME: open using the appropriate program.
+			return false;
+		}
+		if ((type == GCRYSTAL)? Doc->Load (filename): false) {
+normal_exit:
 			GtkRecentData data;
 			data.display_name = (char*) Doc->GetTitle ();
+			if (!(*data.display_name))
+				data.display_name = (char*) Doc->GetLabel ();
 			data.description = NULL;
 			data.mime_type = const_cast<char*> (mime_type);
 			data.app_name = const_cast<char*> ("gcrystal");
@@ -381,3 +409,15 @@ bool gcApplication::OnQuit ()
 	}
 	return true;
 }
+
+void gcApplication::AddMimeType (list<string> &l, string const& mime_type)
+{
+	list<string>::iterator i, iend = l.end ();
+	for (i = l.begin (); i != iend; i++)
+		if (*i == mime_type)
+			break;
+	if (i == iend)
+		l.push_back (mime_type);
+	else
+		g_warning ("Duplicate mime type: %s", mime_type.c_str ());
+}
